==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Dialog.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Dialog = /*@__PURE__*/ (() => {
    class Dialog extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.i = null;
            this.closing = null;
            this.closed = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.i;
        }
        set nativeElement(a) {
            this.i = a;
            this.c.n = this.i;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.d.m("keepOpenOnEscape");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.u("keepOpenOnEscape", value_);
        }
        get e() {
            let ret_ = this.d.m("closeOnOutsideClick");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.u("closeOnOutsideClick", value_);
        }
        get f() {
            let ret_ = this.d.m("hideDefaultAction");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.d.u("hideDefaultAction", value_);
        }
        get h() {
            let ret_ = this.d.m("open");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.u("open", value_);
        }
        get l() {
            let ret_ = this.d.m("title");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.d.u("title", value_);
        }
        get k() {
            let ret_ = this.d.m("returnValue");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.d.u("returnValue", value_);
        }
        closingChanged() {
            if (this.closing != null) {
                this.d.q("closing", (a) => this.closing(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.t("closing");
            }
        }
        closedChanged() {
            if (this.closed != null) {
                this.d.q("closed", (a) => this.closed(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.t("closed");
            }
        }
        q() {
            this.nativeElement.show();
        }
        o() {
            this.nativeElement.hide();
        }
        r() {
            this.nativeElement.toggle();
        }
    }
    Dialog.$t = /*@__PURE__*/ markType(Dialog, 'Dialog', BaseElement.$);
    return Dialog;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Dialog.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let Dialog = /*@__PURE__*/ (() => {
    class Dialog extends BaseElement {
        constructor() {
            super(...arguments);
            this.c = new WCNativeHelper();
            this.i = null;
            this.closing = null;
            this.closed = null;
        }
        get d() {
            return this.c;
        }
        get nativeElement() {
            return this.i;
        }
        set nativeElement(a) {
            this.i = a;
            this.c.o = this.i;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get g() {
            let ret_ = this.d.n("keepOpenOnEscape");
            return ret_;
        }
        set g(a) {
            let value_ = a;
            this.d.v("keepOpenOnEscape", value_);
        }
        get e() {
            let ret_ = this.d.n("closeOnOutsideClick");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.d.v("closeOnOutsideClick", value_);
        }
        get f() {
            let ret_ = this.d.n("hideDefaultAction");
            return ret_;
        }
        set f(a) {
            let value_ = a;
            this.d.v("hideDefaultAction", value_);
        }
        get h() {
            let ret_ = this.d.n("open");
            return ret_;
        }
        set h(a) {
            let value_ = a;
            this.d.v("open", value_);
        }
        get l() {
            let ret_ = this.d.n("title");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.d.v("title", value_);
        }
        get k() {
            let ret_ = this.d.n("returnValue");
            return ret_;
        }
        set k(a) {
            let value_ = a;
            this.d.v("returnValue", value_);
        }
        closingChanged() {
            if (this.closing != null) {
                this.d.r("closing", (a) => this.closing(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.u("closing");
            }
        }
        closedChanged() {
            if (this.closed != null) {
                this.d.r("closed", (a) => this.closed(this, VoidEventArgs.b(a)));
            }
            else {
                this.d.u("closed");
            }
        }
        q() {
            this.nativeElement.show();
        }
        o() {
            this.nativeElement.hide();
        }
        r() {
            this.nativeElement.toggle();
        }
    }
    Dialog.$t = /*@__PURE__*/ markType(Dialog, 'Dialog', BaseElement.$);
    return Dialog;
})();
